package com.bonus.canteen.core.alloc.service;

import java.util.List;
import com.bonus.canteen.core.alloc.domain.AllocCanteenSuggestion;

/**
 * 投诉建议 Service接口
 * 
 * @author xsheng
 * @date 2025-04-20
 */
public interface IAllocCanteenSuggestionService {
    /**
     * 查询投诉建议 
     * 
     * @param id 投诉建议 主键
     * @return 投诉建议 
     */
    public AllocCanteenSuggestion selectAllocCanteenSuggestionById(Long id);

    /**
     * 查询投诉建议 列表
     * 
     * @param allocCanteenSuggestion 投诉建议 
     * @return 投诉建议 集合
     */
    public List<AllocCanteenSuggestion> selectAllocCanteenSuggestionList(AllocCanteenSuggestion allocCanteenSuggestion);

    /**
     * 新增投诉建议 
     * 
     * @param allocCanteenSuggestion 投诉建议 
     * @return 结果
     */
    public int insertAllocCanteenSuggestion(AllocCanteenSuggestion allocCanteenSuggestion);

    /**
     * 修改投诉建议 
     * 
     * @param allocCanteenSuggestion 投诉建议 
     * @return 结果
     */
    public int updateAllocCanteenSuggestion(AllocCanteenSuggestion allocCanteenSuggestion);

    /**
     * 批量删除投诉建议 
     * 
     * @param ids 需要删除的投诉建议 主键集合
     * @return 结果
     */
    public int deleteAllocCanteenSuggestionByIds(Long[] ids);

    /**
     * 删除投诉建议 信息
     * 
     * @param id 投诉建议 主键
     * @return 结果
     */
    public int deleteAllocCanteenSuggestionById(Long id);
}
