package com.bonus.canteen.core.alloc.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.alloc.domain.AllocCanteenSuggestion;
import com.bonus.canteen.core.alloc.service.IAllocCanteenSuggestionService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 投诉建议 Controller
 * 
 * @author xsheng
 * @date 2025-04-20
 */
@Api(tags = "投诉建议 接口")
@RestController
@RequestMapping("/alloc_canteen_suggestion")
public class AllocCanteenSuggestionController extends BaseController {
    @Autowired
    private IAllocCanteenSuggestionService allocCanteenSuggestionService;

    /**
     * 查询投诉建议 列表
     */
    @ApiOperation(value = "查询投诉建议 列表")
    //@RequiresPermissions("alloc:suggestion:list")
    @GetMapping("/list")
    public TableDataInfo list(AllocCanteenSuggestion allocCanteenSuggestion) {
        startPage();
        List<AllocCanteenSuggestion> list = allocCanteenSuggestionService.selectAllocCanteenSuggestionList(allocCanteenSuggestion);
        return getDataTable(list);
    }

    /**
     * 导出投诉建议 列表
     */
    @ApiOperation(value = "导出投诉建议 列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:suggestion:export")
    @SysLog(title = "投诉建议 ", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出投诉建议 ")
    @PostMapping("/export")
    public void export(HttpServletResponse response, AllocCanteenSuggestion allocCanteenSuggestion) {
        List<AllocCanteenSuggestion> list = allocCanteenSuggestionService.selectAllocCanteenSuggestionList(allocCanteenSuggestion);
        ExcelUtil<AllocCanteenSuggestion> util = new ExcelUtil<AllocCanteenSuggestion>(AllocCanteenSuggestion.class);
        util.exportExcel(response, list, "投诉建议 数据");
    }

    /**
     * 获取投诉建议 详细信息
     */
    @ApiOperation(value = "获取投诉建议 详细信息")
    //@RequiresPermissions("alloc:suggestion:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(allocCanteenSuggestionService.selectAllocCanteenSuggestionById(id));
    }

    /**
     * 新增投诉建议 
     */
    @ApiOperation(value = "新增投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:suggestion:add")
    @SysLog(title = "投诉建议 ", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增投诉建议 ")
    @PostMapping
    public AjaxResult add(@RequestBody AllocCanteenSuggestion allocCanteenSuggestion) {
        try {
            return toAjax(allocCanteenSuggestionService.insertAllocCanteenSuggestion(allocCanteenSuggestion));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改投诉建议 
     */
    @ApiOperation(value = "修改投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:suggestion:edit")
    @SysLog(title = "投诉建议 ", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改投诉建议 ")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody AllocCanteenSuggestion allocCanteenSuggestion) {
        try {
            return toAjax(allocCanteenSuggestionService.updateAllocCanteenSuggestion(allocCanteenSuggestion));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除投诉建议 
     */
    @ApiOperation(value = "删除投诉建议 ")
    //@PreventRepeatSubmit
    //@RequiresPermissions("alloc:suggestion:remove")
    @SysLog(title = "投诉建议 ", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除投诉建议 ")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(allocCanteenSuggestionService.deleteAllocCanteenSuggestionByIds(ids));
    }
}
